
% ELO-X Edition of the Better Portrait Poster Latex Template
% 2023-11-06
% Edited and annotated by Rachel Leuthold,
% with advice and beta-testing by Florian Messerer, and inspiration from the templates previously produced by Florian Messerer

% Better Portrait Poster latex template v1.0
% GNU General Public License v3.0
% Daniel Bradford
% https://github.com/drrbradford

% Built on work by Rafael Bailo 
% https://github.com/rafaelbailo/betterposter-latex-template
 
% Original design from Mike Morrison
% https://twitter.com/mikemorrison

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{betterportraitposter}

%% "article" as the base class
\LoadClass{article}
\pagestyle{empty}

%%%% REQUIRED PACKAGES

\RequirePackage{multicol}
\RequirePackage{tcolorbox}

%% Line spacing
\RequirePackage{setspace}

%% Paper size setting
\RequirePackage{geometry} 

%% Font packages
\RequirePackage{cmbright}
\RequirePackage[default]{lato}
\RequirePackage[T1]{fontenc}

% Required to change spaces betweeen enumeration and itemize items
\RequirePackage{enumitem}

% Required for setting custom colors etc.
\RequirePackage{xcolor}

%% Graphics package
\RequirePackage{graphicx}

\usepackage{ifthen}

% AMS packages (optional for math and equations)
\RequirePackage{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}


%%%% Page setup

%% Remove default margins
\geometry{margin=0in}

%% Small separation on enumerate and itemize
\setlist{nolistsep}
\setenumerate{noitemsep}
\setitemize{noitemsep}
\setlength{\parindent}{0pt}

%% Colours
\definecolor{ELOX_purple}{RGB}{53,42,135}
\definecolor{empirical}{RGB}{0,77,64}
\definecolor{theory}{RGB}{26,35,126}
\definecolor{methods}{RGB}{140,22,22}
\definecolor{intervention}{RGB}{255,213,79}

\newcommand{\columnbackgroundcolor}{white}
\newcommand{\columnfontcolor}{black}

\newcommand{\maincolumnbackgroundcolor}{empirical}
\newcommand{\maincolumnfontcolor}{white}

\newcommand{\titlebackgroundcolor}{white}
\newcommand{\titlefontcolor}{black}

\newcommand{\institutefontcolor}{gray}
\newcommand{\authorfontcolor}{gray}

\newcommand{\contentboxframecolor}{\maincolumnbackgroundcolor}
\newcommand{\contentboxtitlecolor}{\maincolumnfontcolor}


\newcommand{\postercolor}[1]{
    \renewcommand{\maincolumnbackgroundcolor}{#1}
    \ifstrequal{#1}{intervention}{
        \renewcommand{\maincolumnfontcolor}{black}
    }
    \ifstrequal{#1}{white}{
        \renewcommand{\maincolumnfontcolor}{black}
        \renewcommand{\contentboxframecolor}{black}
		\renewcommand{\contentboxtitlecolor}{white}
    }
}

\renewcommand\labelitemi{\color{\columnfontcolor}{$\blacktriangleright$}}


%%%% SIZE COMMANDS

%% Poster lengths
\newlength{\mainfindingheight}
\setlength{\mainfindingheight}{0.25\paperheight}

\newlength{\marginvertical}
\setlength{\marginvertical}{0.07\paperheight}

\newlength{\logoboxheight}
\setlength{\logoboxheight}{0.08\paperheight}

\newlength{\contentboxtitleheight}
\setlength{\contentboxtitleheight}{1em}

\setlength{\columnsep}{0.02\textwidth}


%%%% SIZING OPTIONS

\newcommand{\fontsizestandard}{\fontsize{32.00}{50.50} \selectfont}
\newcommand{\fontsizemain}{\fontsize{116.00}{185.00} \selectfont}
\newcommand{\fontsizetitle}{\fontsize{60.00}{80.00} \selectfont}
\newcommand{\fontsizeauthor}{\fontsize{48.00}{68.00} \selectfont}
\newcommand{\fontsizeinstitution}{\fontsize{48.00}{68.00} \selectfont}
\newcommand{\fontsizesection}{\fontsize{48.00}{68.00} \selectfont}

\DeclareOption{a2paper}{
\geometry{a2paper}
\renewcommand{\fontsizestandard}{\fontsize{16.00}{25.00} \selectfont}
\renewcommand{\fontsizemain}{\fontsize{58.00}{110.00} \selectfont}
\renewcommand{\fontsizetitle}{\fontsize{40.00}{50.00} \selectfont}
\renewcommand{\fontsizeauthor}{\fontsize{24.00}{34.00} \selectfont}
\renewcommand{\fontsizeinstitution}{\fontsize{24.00}{34.00} \selectfont}
\renewcommand{\fontsizesection}{\fontsize{24.00}{34.00} \selectfont}
}

\DeclareOption{a1paper}{
\geometry{a1paper}
\renewcommand{\fontsizestandard}{\fontsize{22.63}{35.36} \selectfont}
\renewcommand{\fontsizemain}{\fontsize{82.02}{155.56} \selectfont}
\renewcommand{\fontsizetitle}{\fontsize{56.57}{70.71} \selectfont}
\renewcommand{\fontsizeauthor}{\fontsize{33.94}{48.08} \selectfont}
\renewcommand{\fontsizeinstitution}{\fontsize{33.94}{48.08} \selectfont}
\renewcommand{\fontsizesection}{\fontsize{33.94}{48.08} \selectfont}
}

\DeclareOption{a0paper}{
\geometry{a0paper}
}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax




%% TEMPLATE COMMANDS

% Begin \mainfinding command
\newcommand{\mainfinding}[1]{
    \noindent\colorbox{\maincolumnbackgroundcolor}{
        \begin{minipage}[c][\mainfindingheight][c]{\textwidth}
            \centering
            \fontsizemain\color{\maincolumnfontcolor} 
            \begin{tabular}{p{0.9\textwidth}}
                #1 \\
            \end{tabular}
        \end{minipage}
    }
}
% End \mainfinding command




% Begin \titlebox command
\newcommand{\titlebox}[1]{
    \centering
    \begin{minipage}{0.9\textwidth}
        \vspace{1em}
            #1
    \end{minipage}
}
% End \titlebox command



% Begin \centerbox command
\newcommand{\centerbox}[1]{
    \fontsizestandard\noindent\colorbox{\columnbackgroundcolor}{
        \noindent\hrulefill\par
        \noindent\makebox[\textwidth][c]{%
            \begin{minipage}{0.9\textwidth}
                \vspace{2em}
                \vfill{
                
                    \fontsizestandard\color{\columnfontcolor}
                    #1
                    
                }
                \vspace{2em}
            
            \end{minipage}
        }
    }
}
% End \centerbox command

% Begin \logobox command
\newcommand{\logobox}[1]{
\vspace{-2mm}
    \noindent\colorbox{\maincolumnbackgroundcolor}{
        \begin{minipage}[c][\logoboxheight][c]{\textwidth}
            \centering
            \begin{minipage}{0.9\textwidth}    
	            #1
            \end{minipage}
        \end{minipage}
    }
} 
% End \logobox command

\newcommand{\includeImageWithScalingIntoMinipage}[1]{
	\includegraphics[width=\textwidth, height=0.8\logoboxheight, keepaspectratio]{#1}
}

%% logobox item
\newcommand{\logoboxitem}[2]{
    \begin{minipage}[#1][\logoboxheight][c]{0.3\textwidth}
	\ifthenelse {\equal{#1}{r}}
	{\raggedleft}
	{
		\ifthenelse {\equal{#1}{l}}
		{\raggedright}
		{\centering}
	}		
     \includeImageWithScalingIntoMinipage{#2}
    \end{minipage}
}


%% QR code
\newcommand{\qrcode}[1]{
\logoboxitem{c}{#1}
} 
% End \qrcode command


\newcommand{\addInstituteLogo}[1]{
	\logoboxitem{r}{#1}
}

\newcommand{\addLogoByPosterColor}[3]{
	\ifthenelse
	{
		\equal{\maincolumnbackgroundcolor}{intervention}
	}
	{\logoboxitem{#1}{#2}}
	{
		\ifthenelse
		{
			\equal{\maincolumnbackgroundcolor}{white}
		}
		{\logoboxitem{#1}{#2}}
		{\logoboxitem{#1}{#3}}
	}		
}

\newcommand{\addProjectLogo}{\addLogoByPosterColor{l}{img/elox_logo_light_background.png}{img/elox_logo_dark_background.png}
}

%% Section command
\renewcommand{\section}[1]{
    \vspace{2em}{\fontsizesection\selectfont
    \textbf{\leavevmode
    #1
    }}\\[0.5em]
}
% End \section command

%% Title command
\renewcommand{\title}[1]{
\setstretch{0.75}
\fontsizetitle
\vspace{0.25em}
\textbf{#1}
}
\let\Title\@title


%% Author command
\renewcommand{\author}[1]{
    \vspace{0.25em}
    \fontsizeauthor
    \color{\authorfontcolor}
    #1
}
\let\Author\@author


%% Institution command
\newcommand{\institution}[1]{
    \vspace{0.15em}
    \fontsizeinstitution
    \color{\institutefontcolor}
    #1
}



% This is the definition of a 'normal content' box
\newtcolorbox{contentbox}[2][]{%
    colframe=\contentboxframecolor,
    colback=white,
    coltitle=\contentboxtitlecolor,
    toptitle=\contentboxtitleheight,
    bottomtitle=0.4cm,
    rounded corners,
    arc=0.5cm,
    title={#2\strut},
    #1
}